summaryrefslogtreecommitdiff
path: root/tests/app/Module
diff options
context:
space:
mode:
Diffstat (limited to 'tests/app/Module')
-rw-r--r--tests/app/Module/AhnentafelReportModuleTest.php5
-rw-r--r--tests/app/Module/AlbumModuleTest.php5
-rw-r--r--tests/app/Module/BatchUpdate/BatchUpdateBasePluginTest.php5
-rw-r--r--tests/app/Module/BatchUpdate/BatchUpdateDuplicateLinksPluginTest.php5
-rw-r--r--tests/app/Module/BatchUpdate/BatchUpdateMarriedNamesPluginTest.php5
-rw-r--r--tests/app/Module/BatchUpdate/BatchUpdateMissingDeathPluginTest.php5
-rw-r--r--tests/app/Module/BatchUpdate/BatchUpdateNameFormatPluginTest.php5
-rw-r--r--tests/app/Module/BatchUpdate/BatchUpdateSearchReplacePluginTest.php5
-rw-r--r--tests/app/Module/BatchUpdateModuleTest.php5
-rw-r--r--tests/app/Module/BirthDeathMarriageReportModuleTest.php (renamed from tests/app/Module/BatchUpdate/BirthDeathMarriageReportModuleTest.php)5
-rw-r--r--tests/app/Module/BirthReportModuleTest.php5
-rw-r--r--tests/app/Module/CemeteryReportModuleTest.php5
-rw-r--r--tests/app/Module/CensusAssistantModuleTest.php5
-rw-r--r--tests/app/Module/ChangeReportModuleTest.php5
-rw-r--r--tests/app/Module/ChartsBlockModuleTest.php5
-rw-r--r--tests/app/Module/CkeditorModuleTest.php5
-rw-r--r--tests/app/Module/ClippingsCart/ClippingsCartControllerTest.php (renamed from tests/app/Module/ClippingsCart/ClippingsCartTest.php)9
-rw-r--r--tests/app/Module/ClippingsCartModuleTest.php5
-rw-r--r--tests/app/Module/DeathReportModuleTest.php5
-rw-r--r--tests/app/Module/DescendancyModuleTest.php5
-rw-r--r--tests/app/Module/DescendancyReportModuleTest.php5
-rw-r--r--tests/app/Module/ExtraInformationModuleTest.php5
-rw-r--r--tests/app/Module/FactSourcesReportModuleTest.php5
-rw-r--r--tests/app/Module/FamiliesSidebarModuleTest.php5
-rw-r--r--tests/app/Module/FamilyGroupReportModuleTest.php5
-rw-r--r--tests/app/Module/FamilyNavigatorModuleTest.php5
-rw-r--r--tests/app/Module/FamilyTreeFavoritesModuleTest.php5
-rw-r--r--tests/app/Module/FamilyTreeNewsModuleTest.php5
-rw-r--r--tests/app/Module/FamilyTreeStatisticsModuleTest.php5
-rw-r--r--tests/app/Module/FrequentlyAskedQuestionsModuleTest.php5
-rw-r--r--tests/app/Module/GoogleMapsModuleTest.php5
-rw-r--r--tests/app/Module/HtmlBlockModuleTest.php5
-rw-r--r--tests/app/Module/IndividualFactsTabModuleTest.php5
-rw-r--r--tests/app/Module/IndividualFamiliesReportModuleTest.php5
-rw-r--r--tests/app/Module/IndividualReportModuleTest.php5
-rw-r--r--tests/app/Module/IndividualSidebarModuleTest.php5
-rw-r--r--tests/app/Module/InteractiveTree/TreeViewTest.php5
-rw-r--r--tests/app/Module/InteractiveTreeModuleTest.php5
-rw-r--r--tests/app/Module/LoggedInUsersModuleTest.php5
-rw-r--r--tests/app/Module/MarriageReportModuleTest.php5
-rw-r--r--tests/app/Module/MediaTabModuleTest.php5
-rw-r--r--tests/app/Module/MissingFactsReportModuleTest.php5
-rw-r--r--tests/app/Module/ModuleBlockInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleChartInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleConfigInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleMenuInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleReportInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleSidebarInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleTabInterfaceTest.php5
-rw-r--r--tests/app/Module/ModuleThemeInterfaceTest.php5
-rw-r--r--tests/app/Module/NotesTabModuleTest.php5
-rw-r--r--tests/app/Module/OccupationReportModuleTest.php5
-rw-r--r--tests/app/Module/OnThisDayModuleTest.php5
-rw-r--r--tests/app/Module/PageMenuModuleTest.php5
-rw-r--r--tests/app/Module/PedigreeReportModuleTest.php5
-rw-r--r--tests/app/Module/RecentChangesModuleTest.php5
-rw-r--r--tests/app/Module/RelatedIndividualsReportModuleTest.php5
-rw-r--r--tests/app/Module/RelativesTabModuleTest.php5
-rw-r--r--tests/app/Module/ResearchTaskModuleTest.php5
-rw-r--r--tests/app/Module/ReviewChangesModuleTest.php5
-rw-r--r--tests/app/Module/SiteMapModuleTest.php5
-rw-r--r--tests/app/Module/SlideShowModuleTest.php5
-rw-r--r--tests/app/Module/SourcesTabModuleTest.php5
-rw-r--r--tests/app/Module/StoriesModuleTest.php5
-rw-r--r--tests/app/Module/ThemeSelectModuleTest.php5
-rw-r--r--tests/app/Module/TopGivenNamesModuleTest.php5
-rw-r--r--tests/app/Module/TopPageViewsModuleTest.php5
-rw-r--r--tests/app/Module/TopSurnamesModuleTest.php5
-rw-r--r--tests/app/Module/UpcomingAnniversariesModuleTest.php5
-rw-r--r--tests/app/Module/UserFavoritesModuleTest.php5
-rw-r--r--tests/app/Module/UserJournalModuleTest.php5
-rw-r--r--tests/app/Module/UserMessagesModuleTest.php5
-rw-r--r--tests/app/Module/UserWelcomeModuleTest.php5
-rw-r--r--tests/app/Module/WelcomeBlockModuleTest.php5
-rw-r--r--tests/app/Module/YahrzeitModuleTest.php5
75 files changed, 77 insertions, 302 deletions
diff --git a/tests/app/Module/AhnentafelReportModuleTest.php b/tests/app/Module/AhnentafelReportModuleTest.php
index bef6c09695..b6c2f6f8f7 100644
--- a/tests/app/Module/AhnentafelReportModuleTest.php
+++ b/tests/app/Module/AhnentafelReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class AhnentafelReportModule
*/
@@ -32,6 +29,6 @@ class AhnentafelReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\AhnentafelReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\AhnentafelReportModule'));
}
}
diff --git a/tests/app/Module/AlbumModuleTest.php b/tests/app/Module/AlbumModuleTest.php
index b16f19ff55..7ea884f68e 100644
--- a/tests/app/Module/AlbumModuleTest.php
+++ b/tests/app/Module/AlbumModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class AlbumModule
*/
@@ -32,6 +29,6 @@ class AlbumModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\AlbumModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\AlbumModule'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BatchUpdateBasePluginTest.php b/tests/app/Module/BatchUpdate/BatchUpdateBasePluginTest.php
index dd5b9aaf95..5e2a21f5a4 100644
--- a/tests/app/Module/BatchUpdate/BatchUpdateBasePluginTest.php
+++ b/tests/app/Module/BatchUpdate/BatchUpdateBasePluginTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateBasePlugin
*/
@@ -32,6 +29,6 @@ class BatchUpdateBasePluginTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateBasePlugin'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdate\BatchUpdateBasePlugin'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BatchUpdateDuplicateLinksPluginTest.php b/tests/app/Module/BatchUpdate/BatchUpdateDuplicateLinksPluginTest.php
index 3091bd4bb8..e24a752589 100644
--- a/tests/app/Module/BatchUpdate/BatchUpdateDuplicateLinksPluginTest.php
+++ b/tests/app/Module/BatchUpdate/BatchUpdateDuplicateLinksPluginTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateDuplicateLinksPlugin
*/
@@ -32,6 +29,6 @@ class BatchUpdateDuplicateLinksPluginTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateDuplicateLinksPlugin'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdate\BatchUpdateDuplicateLinksPlugin'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BatchUpdateMarriedNamesPluginTest.php b/tests/app/Module/BatchUpdate/BatchUpdateMarriedNamesPluginTest.php
index 33dfb56456..6ed7da37c7 100644
--- a/tests/app/Module/BatchUpdate/BatchUpdateMarriedNamesPluginTest.php
+++ b/tests/app/Module/BatchUpdate/BatchUpdateMarriedNamesPluginTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateMarriedNamesPlugin
*/
@@ -32,6 +29,6 @@ class BatchUpdateMarriedNamesPluginTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateMarriedNamesPlugin'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdate\BatchUpdateMarriedNamesPlugin'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BatchUpdateMissingDeathPluginTest.php b/tests/app/Module/BatchUpdate/BatchUpdateMissingDeathPluginTest.php
index 8420878b2c..26988646dc 100644
--- a/tests/app/Module/BatchUpdate/BatchUpdateMissingDeathPluginTest.php
+++ b/tests/app/Module/BatchUpdate/BatchUpdateMissingDeathPluginTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateMissingDeathPlugin
*/
@@ -32,6 +29,6 @@ class BatchUpdateMissingDeathPluginTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateMissingDeathPlugin'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdate\BatchUpdateMissingDeathPlugin'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BatchUpdateNameFormatPluginTest.php b/tests/app/Module/BatchUpdate/BatchUpdateNameFormatPluginTest.php
index 6d72099493..27624e0e64 100644
--- a/tests/app/Module/BatchUpdate/BatchUpdateNameFormatPluginTest.php
+++ b/tests/app/Module/BatchUpdate/BatchUpdateNameFormatPluginTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateNameFormatPlugin
*/
@@ -32,6 +29,6 @@ class BatchUpdateNameFormatPluginTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateNameFormatPlugin'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdate\BatchUpdateNameFormatPlugin'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BatchUpdateSearchReplacePluginTest.php b/tests/app/Module/BatchUpdate/BatchUpdateSearchReplacePluginTest.php
index 3c11cae7f8..2a99cea59b 100644
--- a/tests/app/Module/BatchUpdate/BatchUpdateSearchReplacePluginTest.php
+++ b/tests/app/Module/BatchUpdate/BatchUpdateSearchReplacePluginTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateSearchReplacePlugin
*/
@@ -32,6 +29,6 @@ class BatchUpdateSearchReplacePluginTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateSearchReplacePlugin'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdate\BatchUpdateSearchReplacePlugin'));
}
}
diff --git a/tests/app/Module/BatchUpdateModuleTest.php b/tests/app/Module/BatchUpdateModuleTest.php
index eef26f0109..4860800d9b 100644
--- a/tests/app/Module/BatchUpdateModuleTest.php
+++ b/tests/app/Module/BatchUpdateModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BatchUpdateModule
*/
@@ -32,6 +29,6 @@ class BatchUpdateModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BatchUpdateModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BatchUpdateModule'));
}
}
diff --git a/tests/app/Module/BatchUpdate/BirthDeathMarriageReportModuleTest.php b/tests/app/Module/BirthDeathMarriageReportModuleTest.php
index 15032f702c..d25d067586 100644
--- a/tests/app/Module/BatchUpdate/BirthDeathMarriageReportModuleTest.php
+++ b/tests/app/Module/BirthDeathMarriageReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BirthDeathMarriageReportModule
*/
@@ -32,6 +29,6 @@ class BirthDeathMarriageReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BirthDeathMarriageReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BirthDeathMarriageReportModule'));
}
}
diff --git a/tests/app/Module/BirthReportModuleTest.php b/tests/app/Module/BirthReportModuleTest.php
index d89b10680a..660684e99e 100644
--- a/tests/app/Module/BirthReportModuleTest.php
+++ b/tests/app/Module/BirthReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class BirthReportModule
*/
@@ -32,6 +29,6 @@ class BirthReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\BirthReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\BirthReportModule'));
}
}
diff --git a/tests/app/Module/CemeteryReportModuleTest.php b/tests/app/Module/CemeteryReportModuleTest.php
index f817f4fe62..15f5ee0c45 100644
--- a/tests/app/Module/CemeteryReportModuleTest.php
+++ b/tests/app/Module/CemeteryReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class CemeteryReportModule
*/
@@ -32,6 +29,6 @@ class CemeteryReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\CemeteryReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\CemeteryReportModule'));
}
}
diff --git a/tests/app/Module/CensusAssistantModuleTest.php b/tests/app/Module/CensusAssistantModuleTest.php
index 3fe6469a36..7ac3d9edb3 100644
--- a/tests/app/Module/CensusAssistantModuleTest.php
+++ b/tests/app/Module/CensusAssistantModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class CensusAssistantModule
*/
@@ -32,6 +29,6 @@ class CensusAssistantModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\CensusAssistantModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\CensusAssistantModule'));
}
}
diff --git a/tests/app/Module/ChangeReportModuleTest.php b/tests/app/Module/ChangeReportModuleTest.php
index d1c58aa56e..ea6e9ef92d 100644
--- a/tests/app/Module/ChangeReportModuleTest.php
+++ b/tests/app/Module/ChangeReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ChangeReportModule
*/
@@ -32,6 +29,6 @@ class ChangeReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ChangeReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ChangeReportModule'));
}
}
diff --git a/tests/app/Module/ChartsBlockModuleTest.php b/tests/app/Module/ChartsBlockModuleTest.php
index ca80a438c1..0edadd0aa9 100644
--- a/tests/app/Module/ChartsBlockModuleTest.php
+++ b/tests/app/Module/ChartsBlockModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ChartsBlockModule
*/
@@ -32,6 +29,6 @@ class ChartsBlockModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ChartsBlockModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ChartsBlockModule'));
}
}
diff --git a/tests/app/Module/CkeditorModuleTest.php b/tests/app/Module/CkeditorModuleTest.php
index 1cef3402f4..3366a0b364 100644
--- a/tests/app/Module/CkeditorModuleTest.php
+++ b/tests/app/Module/CkeditorModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class CkeditorModule
*/
@@ -32,6 +29,6 @@ class CkeditorModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\CkeditorModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\CkeditorModule'));
}
}
diff --git a/tests/app/Module/ClippingsCartModuleTest.php b/tests/app/Module/ClippingsCartModuleTest.php
index 316427827a..97f4418d8d 100644
--- a/tests/app/Module/ClippingsCartModuleTest.php
+++ b/tests/app/Module/ClippingsCartModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ClippingsCartModule
*/
@@ -32,6 +29,6 @@ class ClippingsCartModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ClippingsCartModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ClippingsCartModule'));
}
}
diff --git a/tests/app/Module/DeathReportModuleTest.php b/tests/app/Module/DeathReportModuleTest.php
index e04eff93a4..7e2256a8f6 100644
--- a/tests/app/Module/DeathReportModuleTest.php
+++ b/tests/app/Module/DeathReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class DeathReportModule
*/
@@ -32,6 +29,6 @@ class DeathReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\DeathReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\DeathReportModule'));
}
}
diff --git a/tests/app/Module/DescendancyModuleTest.php b/tests/app/Module/DescendancyModuleTest.php
index 252f4a3617..6f6ea16274 100644
--- a/tests/app/Module/DescendancyModuleTest.php
+++ b/tests/app/Module/DescendancyModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class DescendancyModule
*/
@@ -32,6 +29,6 @@ class DescendancyModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\DescendancyModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\DescendancyModule'));
}
}
diff --git a/tests/app/Module/DescendancyReportModuleTest.php b/tests/app/Module/DescendancyReportModuleTest.php
index 58b68ab758..5794daced4 100644
--- a/tests/app/Module/DescendancyReportModuleTest.php
+++ b/tests/app/Module/DescendancyReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class DescendancyReportModule
*/
@@ -32,6 +29,6 @@ class DescendancyReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\DescendancyReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\DescendancyReportModule'));
}
}
diff --git a/tests/app/Module/ExtraInformationModuleTest.php b/tests/app/Module/ExtraInformationModuleTest.php
index 533825d9a2..d915452c50 100644
--- a/tests/app/Module/ExtraInformationModuleTest.php
+++ b/tests/app/Module/ExtraInformationModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ExtraInformationModule
*/
@@ -32,6 +29,6 @@ class ExtraInformationModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ExtraInformationModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ExtraInformationModule'));
}
}
diff --git a/tests/app/Module/FactSourcesReportModuleTest.php b/tests/app/Module/FactSourcesReportModuleTest.php
index 4d87f901a2..6b1bf88dcb 100644
--- a/tests/app/Module/FactSourcesReportModuleTest.php
+++ b/tests/app/Module/FactSourcesReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FactSourcesReportModule
*/
@@ -32,6 +29,6 @@ class FactSourcesReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FactSourcesReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FactSourcesReportModule'));
}
}
diff --git a/tests/app/Module/FamiliesSidebarModuleTest.php b/tests/app/Module/FamiliesSidebarModuleTest.php
index 2c163a2b8e..14b5fa0d03 100644
--- a/tests/app/Module/FamiliesSidebarModuleTest.php
+++ b/tests/app/Module/FamiliesSidebarModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FamiliesSidebarModule
*/
@@ -32,6 +29,6 @@ class FamiliesSidebarModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FamiliesSidebarModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FamiliesSidebarModule'));
}
}
diff --git a/tests/app/Module/FamilyGroupReportModuleTest.php b/tests/app/Module/FamilyGroupReportModuleTest.php
index bde467a611..21b0a30b5b 100644
--- a/tests/app/Module/FamilyGroupReportModuleTest.php
+++ b/tests/app/Module/FamilyGroupReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FamilyGroupReportModule
*/
@@ -32,6 +29,6 @@ class FamilyGroupReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FamilyGroupReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FamilyGroupReportModule'));
}
}
diff --git a/tests/app/Module/FamilyNavigatorModuleTest.php b/tests/app/Module/FamilyNavigatorModuleTest.php
index 5ba0073386..ee2cdc69b5 100644
--- a/tests/app/Module/FamilyNavigatorModuleTest.php
+++ b/tests/app/Module/FamilyNavigatorModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FamilyNavigatorModule
*/
@@ -32,6 +29,6 @@ class FamilyNavigatorModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FamilyNavigatorModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FamilyNavigatorModule'));
}
}
diff --git a/tests/app/Module/FamilyTreeFavoritesModuleTest.php b/tests/app/Module/FamilyTreeFavoritesModuleTest.php
index 27c128b121..74a1f074f2 100644
--- a/tests/app/Module/FamilyTreeFavoritesModuleTest.php
+++ b/tests/app/Module/FamilyTreeFavoritesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FamilyTreeFavoritesModule
*/
@@ -32,6 +29,6 @@ class FamilyTreeFavoritesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FamilyTreeFavoritesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FamilyTreeFavoritesModule'));
}
}
diff --git a/tests/app/Module/FamilyTreeNewsModuleTest.php b/tests/app/Module/FamilyTreeNewsModuleTest.php
index bf60846801..a211d806f9 100644
--- a/tests/app/Module/FamilyTreeNewsModuleTest.php
+++ b/tests/app/Module/FamilyTreeNewsModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FamilyTreeNewsModule
*/
@@ -32,6 +29,6 @@ class FamilyTreeNewsModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FamilyTreeNewsModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FamilyTreeNewsModule'));
}
}
diff --git a/tests/app/Module/FamilyTreeStatisticsModuleTest.php b/tests/app/Module/FamilyTreeStatisticsModuleTest.php
index 5efd0c1d43..0774c406ef 100644
--- a/tests/app/Module/FamilyTreeStatisticsModuleTest.php
+++ b/tests/app/Module/FamilyTreeStatisticsModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FamilyTreeStatisticsModule
*/
@@ -32,6 +29,6 @@ class FamilyTreeStatisticsModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FamilyTreeStatisticsModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FamilyTreeStatisticsModule'));
}
}
diff --git a/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php b/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php
index 0aa0b97cfb..e14a8bca92 100644
--- a/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php
+++ b/tests/app/Module/FrequentlyAskedQuestionsModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class FrequentlyAskedQuestionsModule
*/
@@ -32,6 +29,6 @@ class FrequentlyAskedQuestionsModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\FrequentlyAskedQuestionsModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\FrequentlyAskedQuestionsModule'));
}
}
diff --git a/tests/app/Module/GoogleMapsModuleTest.php b/tests/app/Module/GoogleMapsModuleTest.php
index acddaa3f72..9715af17cd 100644
--- a/tests/app/Module/GoogleMapsModuleTest.php
+++ b/tests/app/Module/GoogleMapsModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class GoogleMapsModule
*/
@@ -32,6 +29,6 @@ class GoogleMapsModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\GoogleMapsModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\GoogleMapsModule'));
}
}
diff --git a/tests/app/Module/HtmlBlockModuleTest.php b/tests/app/Module/HtmlBlockModuleTest.php
index 37af7e5d71..deb3296c70 100644
--- a/tests/app/Module/HtmlBlockModuleTest.php
+++ b/tests/app/Module/HtmlBlockModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class HtmlBlockModule
*/
@@ -32,6 +29,6 @@ class HtmlBlockModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\HtmlBlockModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\HtmlBlockModule'));
}
}
diff --git a/tests/app/Module/IndividualFactsTabModuleTest.php b/tests/app/Module/IndividualFactsTabModuleTest.php
index 7f11370cfb..6137503d18 100644
--- a/tests/app/Module/IndividualFactsTabModuleTest.php
+++ b/tests/app/Module/IndividualFactsTabModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class IndividualFactsTabModule
*/
@@ -32,6 +29,6 @@ class IndividualFactsTabModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\IndividualFactsTabModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\IndividualFactsTabModule'));
}
}
diff --git a/tests/app/Module/IndividualFamiliesReportModuleTest.php b/tests/app/Module/IndividualFamiliesReportModuleTest.php
index ed1f62ac32..f4e975d86e 100644
--- a/tests/app/Module/IndividualFamiliesReportModuleTest.php
+++ b/tests/app/Module/IndividualFamiliesReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class IndividualFamiliesReportModule
*/
@@ -32,6 +29,6 @@ class IndividualFamiliesReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\IndividualFamiliesReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\IndividualFamiliesReportModule'));
}
}
diff --git a/tests/app/Module/IndividualReportModuleTest.php b/tests/app/Module/IndividualReportModuleTest.php
index 5200140c80..4460a3dba5 100644
--- a/tests/app/Module/IndividualReportModuleTest.php
+++ b/tests/app/Module/IndividualReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class IndividualReportModule
*/
@@ -32,6 +29,6 @@ class IndividualReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\IndividualReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\IndividualReportModule'));
}
}
diff --git a/tests/app/Module/IndividualSidebarModuleTest.php b/tests/app/Module/IndividualSidebarModuleTest.php
index eb20862f7f..715f585603 100644
--- a/tests/app/Module/IndividualSidebarModuleTest.php
+++ b/tests/app/Module/IndividualSidebarModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class IndividualSidebarModule
*/
@@ -32,6 +29,6 @@ class IndividualSidebarModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\IndividualSidebarModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\IndividualSidebarModule'));
}
}
diff --git a/tests/app/Module/InteractiveTree/TreeViewTest.php b/tests/app/Module/InteractiveTree/TreeViewTest.php
index 6dd11d085c..7646ff3e55 100644
--- a/tests/app/Module/InteractiveTree/TreeViewTest.php
+++ b/tests/app/Module/InteractiveTree/TreeViewTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class TreeView
*/
@@ -32,6 +29,6 @@ class TreeViewTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\TreeView'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\InteractiveTree\TreeView'));
}
}
diff --git a/tests/app/Module/InteractiveTreeModuleTest.php b/tests/app/Module/InteractiveTreeModuleTest.php
index d978928479..5dbbb791f5 100644
--- a/tests/app/Module/InteractiveTreeModuleTest.php
+++ b/tests/app/Module/InteractiveTreeModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class InteractiveTreeModule
*/
@@ -32,6 +29,6 @@ class InteractiveTreeModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\InteractiveTreeModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\InteractiveTreeModule'));
}
}
diff --git a/tests/app/Module/LoggedInUsersModuleTest.php b/tests/app/Module/LoggedInUsersModuleTest.php
index e378c5c754..13feec5f0e 100644
--- a/tests/app/Module/LoggedInUsersModuleTest.php
+++ b/tests/app/Module/LoggedInUsersModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class LoggedInUsersModule
*/
@@ -32,6 +29,6 @@ class LoggedInUsersModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\LoggedInUsersModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\LoggedInUsersModule'));
}
}
diff --git a/tests/app/Module/MarriageReportModuleTest.php b/tests/app/Module/MarriageReportModuleTest.php
index c50ab3d8d0..b52241a9d4 100644
--- a/tests/app/Module/MarriageReportModuleTest.php
+++ b/tests/app/Module/MarriageReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class MarriageReportModule
*/
@@ -32,6 +29,6 @@ class MarriageReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\MarriageReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\MarriageReportModule'));
}
}
diff --git a/tests/app/Module/MediaTabModuleTest.php b/tests/app/Module/MediaTabModuleTest.php
index 2d28e7877b..6025e21d73 100644
--- a/tests/app/Module/MediaTabModuleTest.php
+++ b/tests/app/Module/MediaTabModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class MediaTabModule
*/
@@ -32,6 +29,6 @@ class MediaTabModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\MediaTabModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\MediaTabModule'));
}
}
diff --git a/tests/app/Module/MissingFactsReportModuleTest.php b/tests/app/Module/MissingFactsReportModuleTest.php
index 98d7067b82..1410184844 100644
--- a/tests/app/Module/MissingFactsReportModuleTest.php
+++ b/tests/app/Module/MissingFactsReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class MissingFactsReportModule
*/
@@ -32,6 +29,6 @@ class MissingFactsReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\MissingFactsReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\MissingFactsReportModule'));
}
}
diff --git a/tests/app/Module/ModuleBlockInterfaceTest.php b/tests/app/Module/ModuleBlockInterfaceTest.php
index bff2d7a7f3..1a0004a531 100644
--- a/tests/app/Module/ModuleBlockInterfaceTest.php
+++ b/tests/app/Module/ModuleBlockInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleBlockInterface
*/
@@ -32,6 +29,6 @@ class ModuleBlockInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleBlockInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleBlockInterface'));
}
}
diff --git a/tests/app/Module/ModuleChartInterfaceTest.php b/tests/app/Module/ModuleChartInterfaceTest.php
index fafba3d7c0..2024fe9b1f 100644
--- a/tests/app/Module/ModuleChartInterfaceTest.php
+++ b/tests/app/Module/ModuleChartInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleChartInterface
*/
@@ -32,6 +29,6 @@ class ModuleChartInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleChartInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleChartInterface'));
}
}
diff --git a/tests/app/Module/ModuleConfigInterfaceTest.php b/tests/app/Module/ModuleConfigInterfaceTest.php
index 2f9e84e09b..e1a464cc68 100644
--- a/tests/app/Module/ModuleConfigInterfaceTest.php
+++ b/tests/app/Module/ModuleConfigInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleConfigInterface
*/
@@ -32,6 +29,6 @@ class ModuleConfigInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleConfigInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleConfigInterface'));
}
}
diff --git a/tests/app/Module/ModuleMenuInterfaceTest.php b/tests/app/Module/ModuleMenuInterfaceTest.php
index 28dc37393e..be1c833247 100644
--- a/tests/app/Module/ModuleMenuInterfaceTest.php
+++ b/tests/app/Module/ModuleMenuInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleMenuInterface
*/
@@ -32,6 +29,6 @@ class ModuleMenuInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleMenuInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleMenuInterface'));
}
}
diff --git a/tests/app/Module/ModuleReportInterfaceTest.php b/tests/app/Module/ModuleReportInterfaceTest.php
index eb0655d0b9..a1171fc4f1 100644
--- a/tests/app/Module/ModuleReportInterfaceTest.php
+++ b/tests/app/Module/ModuleReportInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleReportInterface
*/
@@ -32,6 +29,6 @@ class ModuleReportInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleReportInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleReportInterface'));
}
}
diff --git a/tests/app/Module/ModuleSidebarInterfaceTest.php b/tests/app/Module/ModuleSidebarInterfaceTest.php
index 49fc8e9179..253bb36a9d 100644
--- a/tests/app/Module/ModuleSidebarInterfaceTest.php
+++ b/tests/app/Module/ModuleSidebarInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleSidebarInterface
*/
@@ -32,6 +29,6 @@ class ModuleSidebarInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleSidebarInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleSidebarInterface'));
}
}
diff --git a/tests/app/Module/ModuleTabInterfaceTest.php b/tests/app/Module/ModuleTabInterfaceTest.php
index d6ed2d3cc4..e54eb86954 100644
--- a/tests/app/Module/ModuleTabInterfaceTest.php
+++ b/tests/app/Module/ModuleTabInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleTabInterface
*/
@@ -32,6 +29,6 @@ class ModuleTabInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleTabInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleTabInterface'));
}
}
diff --git a/tests/app/Module/ModuleThemeInterfaceTest.php b/tests/app/Module/ModuleThemeInterfaceTest.php
index ff9861136e..d8535bfb92 100644
--- a/tests/app/Module/ModuleThemeInterfaceTest.php
+++ b/tests/app/Module/ModuleThemeInterfaceTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ModuleThemeInterface
*/
@@ -32,6 +29,6 @@ class ModuleThemeInterfaceTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(interface_exists(__NAMESPACE__ . '\ModuleThemeInterface'));
+ $this->assertTrue(interface_exists('\Fisharebest\Webtrees\Module\ModuleThemeInterface'));
}
}
diff --git a/tests/app/Module/NotesTabModuleTest.php b/tests/app/Module/NotesTabModuleTest.php
index d063480d0b..539b332c47 100644
--- a/tests/app/Module/NotesTabModuleTest.php
+++ b/tests/app/Module/NotesTabModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class NotesTabModule
*/
@@ -32,6 +29,6 @@ class NotesTabModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\NotesTabModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\NotesTabModule'));
}
}
diff --git a/tests/app/Module/OccupationReportModuleTest.php b/tests/app/Module/OccupationReportModuleTest.php
index e4a9300051..0a1a316e48 100644
--- a/tests/app/Module/OccupationReportModuleTest.php
+++ b/tests/app/Module/OccupationReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class OccupationReportModule
*/
@@ -32,6 +29,6 @@ class OccupationReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\OccupationReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\OccupationReportModule'));
}
}
diff --git a/tests/app/Module/OnThisDayModuleTest.php b/tests/app/Module/OnThisDayModuleTest.php
index a00c66653c..e3e1038096 100644
--- a/tests/app/Module/OnThisDayModuleTest.php
+++ b/tests/app/Module/OnThisDayModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class OnThisDayModule
*/
@@ -32,6 +29,6 @@ class OnThisDayModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\OnThisDayModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\OnThisDayModule'));
}
}
diff --git a/tests/app/Module/PageMenuModuleTest.php b/tests/app/Module/PageMenuModuleTest.php
index 86635d9e4d..8cd5e941fb 100644
--- a/tests/app/Module/PageMenuModuleTest.php
+++ b/tests/app/Module/PageMenuModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class PageMenuModule
*/
@@ -32,6 +29,6 @@ class PageMenuModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\PageMenuModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\PageMenuModule'));
}
}
diff --git a/tests/app/Module/PedigreeReportModuleTest.php b/tests/app/Module/PedigreeReportModuleTest.php
index 7c44440217..d88d2d6b51 100644
--- a/tests/app/Module/PedigreeReportModuleTest.php
+++ b/tests/app/Module/PedigreeReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class PedigreeReportModule
*/
@@ -32,6 +29,6 @@ class PedigreeReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\PedigreeReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\PedigreeReportModule'));
}
}
diff --git a/tests/app/Module/RecentChangesModuleTest.php b/tests/app/Module/RecentChangesModuleTest.php
index bb49446d66..5ccc6ba8c6 100644
--- a/tests/app/Module/RecentChangesModuleTest.php
+++ b/tests/app/Module/RecentChangesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class RecentChangesModule
*/
@@ -32,6 +29,6 @@ class RecentChangesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\RecentChangesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\RecentChangesModule'));
}
}
diff --git a/tests/app/Module/RelatedIndividualsReportModuleTest.php b/tests/app/Module/RelatedIndividualsReportModuleTest.php
index a6a491e8ff..ea2e866f7a 100644
--- a/tests/app/Module/RelatedIndividualsReportModuleTest.php
+++ b/tests/app/Module/RelatedIndividualsReportModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class RelatedIndividualsReportModule
*/
@@ -32,6 +29,6 @@ class RelatedIndividualsReportModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\RelatedIndividualsReportModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\RelatedIndividualsReportModule'));
}
}
diff --git a/tests/app/Module/RelativesTabModuleTest.php b/tests/app/Module/RelativesTabModuleTest.php
index b3acc47727..43da392ce4 100644
--- a/tests/app/Module/RelativesTabModuleTest.php
+++ b/tests/app/Module/RelativesTabModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class RelativesTabModule
*/
@@ -32,6 +29,6 @@ class RelativesTabModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\RelativesTabModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\RelativesTabModule'));
}
}
diff --git a/tests/app/Module/ResearchTaskModuleTest.php b/tests/app/Module/ResearchTaskModuleTest.php
index f66d670479..cd481c20fb 100644
--- a/tests/app/Module/ResearchTaskModuleTest.php
+++ b/tests/app/Module/ResearchTaskModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ResearchTaskModule
*/
@@ -32,6 +29,6 @@ class ResearchTaskModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ResearchTaskModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ResearchTaskModule'));
}
}
diff --git a/tests/app/Module/ReviewChangesModuleTest.php b/tests/app/Module/ReviewChangesModuleTest.php
index f9b05b648c..a440ddc232 100644
--- a/tests/app/Module/ReviewChangesModuleTest.php
+++ b/tests/app/Module/ReviewChangesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ReviewChangesModule
*/
@@ -32,6 +29,6 @@ class ReviewChangesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ReviewChangesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ReviewChangesModule'));
}
}
diff --git a/tests/app/Module/SiteMapModuleTest.php b/tests/app/Module/SiteMapModuleTest.php
index 2429948548..1a06b8cc6d 100644
--- a/tests/app/Module/SiteMapModuleTest.php
+++ b/tests/app/Module/SiteMapModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class SiteMapModule
*/
@@ -32,6 +29,6 @@ class SiteMapModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\SiteMapModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\SiteMapModule'));
}
}
diff --git a/tests/app/Module/SlideShowModuleTest.php b/tests/app/Module/SlideShowModuleTest.php
index fd136eb0bb..a196d4ac2b 100644
--- a/tests/app/Module/SlideShowModuleTest.php
+++ b/tests/app/Module/SlideShowModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class SlideShowModule
*/
@@ -32,6 +29,6 @@ class SlideShowModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\SlideShowModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\SlideShowModule'));
}
}
diff --git a/tests/app/Module/SourcesTabModuleTest.php b/tests/app/Module/SourcesTabModuleTest.php
index e785af9449..804a4edb6e 100644
--- a/tests/app/Module/SourcesTabModuleTest.php
+++ b/tests/app/Module/SourcesTabModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class SourcesTabModule
*/
@@ -32,6 +29,6 @@ class SourcesTabModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\SourcesTabModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\SourcesTabModule'));
}
}
diff --git a/tests/app/Module/StoriesModuleTest.php b/tests/app/Module/StoriesModuleTest.php
index ffcccc48d1..10272c492d 100644
--- a/tests/app/Module/StoriesModuleTest.php
+++ b/tests/app/Module/StoriesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class StoriesModule
*/
@@ -32,6 +29,6 @@ class StoriesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\StoriesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\StoriesModule'));
}
}
diff --git a/tests/app/Module/ThemeSelectModuleTest.php b/tests/app/Module/ThemeSelectModuleTest.php
index 581a15a7ba..4200c825f2 100644
--- a/tests/app/Module/ThemeSelectModuleTest.php
+++ b/tests/app/Module/ThemeSelectModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ThemeSelectModule
*/
@@ -32,6 +29,6 @@ class ThemeSelectModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ThemeSelectModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ThemeSelectModule'));
}
}
diff --git a/tests/app/Module/TopGivenNamesModuleTest.php b/tests/app/Module/TopGivenNamesModuleTest.php
index 1bd8b75030..69c599a395 100644
--- a/tests/app/Module/TopGivenNamesModuleTest.php
+++ b/tests/app/Module/TopGivenNamesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class TopGivenNamesModuleModule
*/
@@ -32,6 +29,6 @@ class TopGivenNamesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\TopGivenNamesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\TopGivenNamesModule'));
}
}
diff --git a/tests/app/Module/TopPageViewsModuleTest.php b/tests/app/Module/TopPageViewsModuleTest.php
index df192aea03..8ba5318bba 100644
--- a/tests/app/Module/TopPageViewsModuleTest.php
+++ b/tests/app/Module/TopPageViewsModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class TopPageViewsModule
*/
@@ -32,6 +29,6 @@ class TopPageViewsModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\TopPageViewsModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\TopPageViewsModule'));
}
}
diff --git a/tests/app/Module/TopSurnamesModuleTest.php b/tests/app/Module/TopSurnamesModuleTest.php
index 0d29310d11..33377295f3 100644
--- a/tests/app/Module/TopSurnamesModuleTest.php
+++ b/tests/app/Module/TopSurnamesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class TopSurnamesModule
*/
@@ -32,6 +29,6 @@ class TopSurnamesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\TopSurnamesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\TopSurnamesModule'));
}
}
diff --git a/tests/app/Module/UpcomingAnniversariesModuleTest.php b/tests/app/Module/UpcomingAnniversariesModuleTest.php
index 1594979d33..4bd355ccfa 100644
--- a/tests/app/Module/UpcomingAnniversariesModuleTest.php
+++ b/tests/app/Module/UpcomingAnniversariesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class UpcomingAnniversariesModule
*/
@@ -32,6 +29,6 @@ class UpcomingAnniversariesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\UpcomingAnniversariesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\UpcomingAnniversariesModule'));
}
}
diff --git a/tests/app/Module/UserFavoritesModuleTest.php b/tests/app/Module/UserFavoritesModuleTest.php
index dcd690fdc2..0634c39f25 100644
--- a/tests/app/Module/UserFavoritesModuleTest.php
+++ b/tests/app/Module/UserFavoritesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class UserFavoritesModule
*/
@@ -32,6 +29,6 @@ class UserFavoritesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\UserFavoritesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\UserFavoritesModule'));
}
}
diff --git a/tests/app/Module/UserJournalModuleTest.php b/tests/app/Module/UserJournalModuleTest.php
index 3704c0d581..40172aeb32 100644
--- a/tests/app/Module/UserJournalModuleTest.php
+++ b/tests/app/Module/UserJournalModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class UserJournalModule
*/
@@ -32,6 +29,6 @@ class UserJournalModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\UserJournalModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\UserJournalModule'));
}
}
diff --git a/tests/app/Module/UserMessagesModuleTest.php b/tests/app/Module/UserMessagesModuleTest.php
index 57f7b99511..e873a67469 100644
--- a/tests/app/Module/UserMessagesModuleTest.php
+++ b/tests/app/Module/UserMessagesModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class UserMessagesModule
*/
@@ -32,6 +29,6 @@ class UserMessagesModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\UserMessagesModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\UserMessagesModule'));
}
}
diff --git a/tests/app/Module/UserWelcomeModuleTest.php b/tests/app/Module/UserWelcomeModuleTest.php
index 527ed296a7..5ccc261a62 100644
--- a/tests/app/Module/UserWelcomeModuleTest.php
+++ b/tests/app/Module/UserWelcomeModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class UserWelcomeModule
*/
@@ -32,6 +29,6 @@ class UserWelcomeModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\UserWelcomeModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\UserWelcomeModule'));
}
}
diff --git a/tests/app/Module/WelcomeBlockModuleTest.php b/tests/app/Module/WelcomeBlockModuleTest.php
index 9790ea1aff..0d3eff0748 100644
--- a/tests/app/Module/WelcomeBlockModuleTest.php
+++ b/tests/app/Module/WelcomeBlockModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class WelcomeBlockModule
*/
@@ -32,6 +29,6 @@ class WelcomeBlockModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\WelcomeBlockModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\WelcomeBlockModule'));
}
}
diff --git a/tests/app/Module/YahrzeitModuleTest.php b/tests/app/Module/YahrzeitModuleTest.php
index e31c89b597..f349cdb4d6 100644
--- a/tests/app/Module/YahrzeitModuleTest.php
+++ b/tests/app/Module/YahrzeitModuleTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,8 +15,6 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class YahrzeitModule
*/
@@ -32,6 +29,6 @@ class YahrzeitModuleTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\YahrzeitModule'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\YahrzeitModule'));
}
}
diff --git a/tests/app/Module/ClippingsCart/ClippingsCartTest.php b/tests/app/Module/ClippingsCart/ClippingsCartControllerTest.php
index 83835a3146..ced778f195 100644
--- a/tests/app/Module/ClippingsCart/ClippingsCartTest.php
+++ b/tests/app/Module/ClippingsCart/ClippingsCartControllerTest.php
@@ -1,5 +1,4 @@
<?php
-namespace Fisharebest\Webtrees;
/**
* webtrees: online genealogy
@@ -16,12 +15,10 @@ namespace Fisharebest\Webtrees;
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-use PHPUnit_Framework_TestCase;
-
/**
* Test harness for the class ClippingsCart
*/
-class ClippingsCartTest extends PHPUnit_Framework_TestCase {
+class ClippingsCartControllerTest extends PHPUnit_Framework_TestCase {
/**
* Prepare the environment for these tests
*/
@@ -32,6 +29,6 @@ class ClippingsCartTest extends PHPUnit_Framework_TestCase {
* Test that the class exists
*/
public function testClassExists() {
- $this->assertTrue(class_exists(__NAMESPACE__ . '\ClippingsCart'));
+ $this->assertTrue(class_exists('\Fisharebest\Webtrees\Module\ClippingsCart\ClippingsCartController'));
}
}
@@ -16,12 +15,10 @@ namespace Fisharebest\Webtrees;
/**
- * Test harness for the class ClippingsCart
+ * Test harness for the class ClippingsCartController
*/